@@ -94,7 +94,7 @@ def read_md_problem(filepath):
             - `num_parts` - Number of parts in the problem (integer).
     """
 
-    mdtext = pathlib.Path(filepath).read_text()
+    mdtext = pathlib.Path(filepath).read_text(encoding='raw_unicode_escape')
 
     # Deal with YAML header
     header_text = mdtext.rsplit('---\n')[1]
@@ -277,9 +277,9 @@ def process_dropdown(part_name,parsed_question, data_dict):
     Returns:
         html: A string of HTML that is part of the final PL question.html file.
     """
-
-    raise NotImplementedError
-
+    html = process_multiple_choice(part_name,parsed_question, data_dict).replace('-multiple-choice','-dropdown')
+    return html
+    
 def process_number_input(part_name,parsed_question, data_dict):
     """Processes markdown format number-input questions and returns PL HTML
 
@@ -354,16 +354,16 @@ def process_attribution(source):
         string (str): returns the html of the attribution
     """
 
-    if source == 'openstax-physics-vol1':
+    if 'openstax-physics-vol1' in source:
         attribution_text = "![Image representing the Creative Commons 4.0 BY license.](https://i.creativecommons.org/l/by/4.0/88x31.png) Problem is from the [OpenStax University Physics Volume 1](https://openstax.org/details/books/university-physics-volume-1) textbook, licensed under the [CC-BY 4.0 license](https://creativecommons.org/licenses/by/4.0/)."
 
-    elif source == 'openstax-physics-vol2':
+    elif 'openstax-physics-vol2' in source:
         attribution_text = "![Image representing the Creative Commons 4.0 BY license.](https://i.creativecommons.org/l/by/4.0/88x31.png) Problem is from the [OpenStax University Physics Volume 2](https://openstax.org/details/books/university-physics-volume-2) textbook, licensed under the [CC-BY 4.0 license](https://creativecommons.org/licenses/by/4.0/)."
 
-    elif source == 'ubc-mech2':
+    elif 'ubc-mech2' in source:
         raise NotImplementedError
 
-    elif source is None or source =='standard':
+    elif 'standard' in source:
         attribution_text = "![Image representing the Creative Commons 4.0 BY-NC-SA license.](https://mirrors.creativecommons.org/presskit/buttons/88x31/png/by-nc-sa.png) Problem is licensed under the [CC-BY-NC-SA 4.0 license](https://creativecommons.org/licenses/by-nc-sa/4.0/)."
 
     return attribution_text
@@ -408,6 +408,8 @@ def process_question(input_file, output_path):
             question_html = process_checkbox('part1',parsed_q,data2)
         elif 'symbolic-input' in q_type:
             question_html = process_symbolic_input('part1',parsed_q,data2)
+        elif 'dropdown' in q_type:
+            question_html = process_dropdown('part1',parsed_q,data2)
         else:
             raise NotImplementedError(f"This question type ({q_type}) is not yet implemented.")
 
@@ -418,13 +420,10 @@ def process_question(input_file, output_path):
             part = 'part'+f'{pnum}'
             q_type = parsed_q['header'][part]['type']
 
-            question_html += f"""
-                <div class="card my-2">
-                \t<div class="card-header">
-                \t{parsed_q['body_parts_split'][part]['title']}
-                </div>\n
-                <div class="card-body">\n\n\n
-                """
+            question_html += f"""<div class="card my-2">
+<div class="card-header">{parsed_q['body_parts_split'][part]['title']}</div>\n
+<div class="card-body">\n\n"""
+
             if 'multiple-choice' in q_type:                
                 question_html += f"{process_multiple_choice(part,parsed_q,data2)}"  
             elif 'number-input' in q_type:
@@ -433,16 +432,23 @@ def process_question(input_file, output_path):
                 question_html += process_checkbox(part,parsed_q,data2)
             elif 'symbolic-input' in q_type:
                 question_html += process_symbolic_input(part,parsed_q,data2)
+            elif 'dropdown' in q_type:
+                question_html += process_dropdown(part,parsed_q,data2)
             else:
                 raise NotImplementedError(f"This question type ({q_type}) is not yet implemented.")
 
-            question_html += "</div>\n</div>\n\n"
+
+            question_html += "</div>\n</div>\n\n\n"
 
     # Add Attribution
-    question_html += f"\n\n---<markdown>\n{process_attribution(parsed_q['header'].get('attribution'))}\n</markdown>"
+    question_html += f"\n\n<markdown>---\n{process_attribution(parsed_q['header'].get('attribution'))}\n</markdown>"
 
     # Write question.html file
-    (output_path / "question.html").write_text(question_html)
+    #(output_path / "question.html").write_text(question_html,encoding='raw_unicode_escape')
+
+    ### TODO solve the issue with the latex escape sequences, this is a workaround
+    with open((output_path / "question.html"), "w") as qfile:
+        print(f"{question_html}", file=qfile)
 
     # Write server.py file
     write_server_py(output_path,parsed_q)
